# Exercise 4: Multivariable analysis in R part 2: Cox proportional hazard model

rm(list=ls())

library(survival)

e_ex04a <- read.table("e_ex02_02.dat")
names(e_ex04a)

e_ex04b <- e_ex04a[c(1:4, 8)]

attach(e_ex04b)
e_ex04b$fq03[fq04 == "Susceptible"]           <- "1-Susceptible"
e_ex04b$fq03[fq04 == "Low-level resistance"]  <- "2-Low-level resistance"
e_ex04b$fq03[fq04 == "High-level resistance"] <- "3-High-level resistance"
e_ex04b$out02[outcome02 == "Success"] <- 0
e_ex04b$out02[outcome02 == "Failure"] <- 1
detach(e_ex04b)
names(e_ex04b)
e_ex04c <- e_ex04b[c(1, 3:4, 6:7)]
attach(e_ex04c)
names(e_ex04c)

# Reproducing the Kaplan-Meier lifetable analysis from EpiData Analysis
fit1 <- survfit(formula=Surv(totobstime, out02) ~ fq03, data=e_ex04c)
plot(fit1, col = c(1, 2, 4), ymin=0.45)
# colors: 1=black; 2=red, 4=blue
summary(fit1, times = seq(0, 2000, 30))

# Cox proportional hazard model
mdrcox  <- coxph(Surv(totobstime, out02) ~ factor(fq03) + factor(sex) + age, data=e_ex04c)
summary(mdrcox)
cox.zph(mdrcox)

mdrcox  <- coxph(Surv(totobstime, out02) ~ strata(fq03) + factor(sex) + age, data=e_ex04c)
summary(mdrcox)
cox.zph(mdrcox)
plot(cox.zph(mdrcox))

p  <- plot(survfit(mdrcox), ylim=c(.45, 1), xlab="Days since treatment start", mark.time=F, ylab="Probability of a successful outcome",  col=c(1, 2, 4), main="Cox proportional hazard model by initial fluoroquinolone resistance")
print(p)

mdrcox2 <- survfit(mdrcox)
summary(mdrcox2, times = seq(0, 3000, 30))
summary(mdrcox2, times = seq(0, 5, 1))
